import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { describe, it, expect, jest } from '@jest/globals';
import { render, screen, waitFor } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { DropdownMenu } from '.';
import { openDropdownMenu } from '../../test-utils/rtl';
import { Button } from '../Button';
import { DesignSystemEventProvider } from '../DesignSystemEventProvider/DesignSystemEventProvider';
import { DesignSystemProvider } from '../DesignSystemProvider';
describe('DropdownMenu', function () {
    function renderComponent() {
        return render(_jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_15", "data-testid": "test-menubutton", children: "Default" }) }), _jsxs(DropdownMenu.Content, { align: "start", children: [_jsxs(DropdownMenu.Sub, { children: [_jsx(DropdownMenu.SubTrigger, { children: "Option 1" }), _jsxs(DropdownMenu.SubContent, { children: [_jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_27", children: "Option 1a" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_28", children: "Option 1b" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_29", children: "Option 1c" })] })] }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_32", children: "Option 2" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_33", children: "Option 3" })] })] }) }));
    }
    function renderDisabledComponentWithTooltip(onClick) {
        return render(_jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_39", "data-testid": "test-menubutton", children: "Default" }) }), _jsxs(DropdownMenu.Content, { align: "start", children: [_jsxs(DropdownMenu.Sub, { children: [_jsx(DropdownMenu.SubTrigger, { children: "Option 1" }), _jsxs(DropdownMenu.SubContent, { children: [_jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_56", children: "Option 1a" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_57", children: "Option 1b" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_58", children: "Option 1c" })] })] }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_61", "data-testid": "test-disableditem", disabled: true, disabledReason: "Option disabled reason", onClick: onClick, children: "Option 2" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_69", children: "Option 3" })] })] }) }));
    }
    // This is a trivial re-test of Radix's tests, but is provided as an
    // example of how to test the DropdownMenu component.
    it('renders proper number of menuitem(s) with proper text', async () => {
        renderComponent();
        await userEvent.click(screen.getByTestId('test-menubutton'));
        expect(screen.queryAllByRole('menuitem')).toHaveLength(3);
        expect(screen.queryByText('Option 1')).not.toBeNull();
        expect(screen.queryByText('Option 2')).not.toBeNull();
        expect(screen.queryByText('Option 3')).not.toBeNull();
        // This is known to not work correctly in `@testing-library/user-event <=13.5.0.
        await userEvent.click(screen.getByText('Option 1'));
        expect(screen.queryAllByRole('menuitem')).toHaveLength(6);
        await userEvent.keyboard('{Escape}');
        expect(screen.queryAllByRole('menuitem')).toHaveLength(0);
    });
    it("doesn't trigger click on tooltip event when disabled", async () => {
        const onClick = jest.fn();
        renderDisabledComponentWithTooltip(onClick);
        openDropdownMenu(screen.getByTestId('test-menubutton'));
        await waitFor(() => {
            expect(screen.getByTestId('test-disableditem')).toBeVisible();
        });
        userEvent.click(screen.getByTestId('test-disableditem').querySelector('span'));
        expect(onClick).not.toHaveBeenCalled();
    });
    it('emits analytics events for item', async () => {
        const handleClick = jest.fn();
        const eventCallback = jest.fn();
        render(_jsx(DesignSystemEventProvider, { callback: eventCallback, children: _jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_15", "data-testid": "test-menubutton", children: "Default" }) }), _jsxs(DropdownMenu.Content, { align: "start", children: [_jsx(DropdownMenu.Item, { onClick: handleClick, componentId: "OPTION_A_TEST", children: "Option A" }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_132", children: "Option B" })] })] }) }) }));
        expect(handleClick).not.toBeCalled();
        expect(eventCallback).not.toBeCalled();
        await userEvent.click(screen.getByTestId('test-menubutton'));
        expect(screen.queryAllByRole('menuitem')).toHaveLength(2);
        await userEvent.click(screen.getByText('Option A'));
        expect(handleClick).toHaveBeenCalledTimes(1);
        expect(eventCallback).toHaveBeenNthCalledWith(1, {
            eventType: 'onClick',
            componentId: 'OPTION_A_TEST',
            componentType: 'dropdown_menu_item',
            componentSubType: undefined,
            shouldStartInteraction: true,
            value: undefined,
            event: expect.any(Object),
            isInteractionSubject: true,
        });
    });
    it('does not emit analytics events for menu item with asChild set', async () => {
        const handleClick = jest.fn();
        const eventCallback = jest.fn();
        render(_jsx(DesignSystemEventProvider, { callback: eventCallback, children: _jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_15", "data-testid": "test-menubutton", children: "Default" }) }), _jsxs(DropdownMenu.Content, { align: "start", children: [_jsx(DropdownMenu.Item, { onClick: handleClick, componentId: "OPTION_A_TEST", asChild: true, children: _jsx(Button, { componentId: "OPTION_A_TEST_CHILD", children: "Option A" }) }), _jsx(DropdownMenu.Item, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_174", children: "Option B" })] })] }) }) }));
        expect(handleClick).not.toBeCalled();
        expect(eventCallback).not.toBeCalled();
        await userEvent.click(screen.getByTestId('test-menubutton'));
        expect(screen.queryAllByRole('menuitem')).toHaveLength(2);
        await userEvent.click(screen.getByText('Option A'));
        expect(handleClick).toHaveBeenCalledTimes(1);
        expect(eventCallback).toHaveBeenCalledTimes(1);
        expect(eventCallback).toHaveBeenNthCalledWith(1, {
            eventType: 'onClick',
            componentId: 'OPTION_A_TEST_CHILD',
            componentType: 'button',
            shouldStartInteraction: true,
            isInteractionSubject: true,
            value: undefined,
            event: expect.anything(),
        });
    });
    it('emits analytics events for checkbox', async () => {
        const handleClick = jest.fn();
        const eventCallback = jest.fn();
        render(_jsx(DesignSystemEventProvider, { callback: eventCallback, children: _jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_15", "data-testid": "test-menubutton", children: "Default" }) }), _jsxs(DropdownMenu.Content, { align: "start", children: [_jsx(DropdownMenu.CheckboxItem, { onCheckedChange: handleClick, componentId: "OPTION_A_TEST", children: "Option A" }), _jsx(DropdownMenu.CheckboxItem, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_218", children: "Option B" })] })] }) }) }));
        expect(handleClick).not.toBeCalled();
        expect(eventCallback).not.toBeCalled();
        await userEvent.click(screen.getByTestId('test-menubutton'));
        await userEvent.click(screen.getByText('Option A'));
        expect(handleClick).toHaveBeenCalledTimes(1);
        expect(eventCallback).toHaveBeenNthCalledWith(1, {
            eventType: 'onValueChange',
            componentId: 'OPTION_A_TEST',
            componentType: 'dropdown_menu_checkbox_item',
            shouldStartInteraction: false,
            value: true,
        });
    });
    it('emits analytics events for radio group', async () => {
        const handleClick = jest.fn();
        const eventCallback = jest.fn();
        render(_jsx(DesignSystemEventProvider, { callback: eventCallback, children: _jsx(DesignSystemProvider, { children: _jsxs(DropdownMenu.Root, { children: [_jsx(DropdownMenu.Trigger, { asChild: true, children: _jsx(Button, { componentId: "codegen_design-system_src_design-system_dropdownmenu_dropdownmenu.test.tsx_15", "data-testid": "test-menubutton", children: "Default" }) }), _jsx(DropdownMenu.Content, { align: "start", children: _jsxs(DropdownMenu.RadioGroup, { componentId: "OPTION_RADIO_GROUP", children: [_jsx(DropdownMenu.RadioItem, { value: "A", onClick: handleClick, children: "Option A" }), _jsx(DropdownMenu.RadioItem, { value: "B", children: "Option B" })] }) })] }) }) }));
        expect(handleClick).not.toBeCalled();
        expect(eventCallback).not.toBeCalled();
        await userEvent.click(screen.getByTestId('test-menubutton'));
        await userEvent.click(screen.getByText('Option A'));
        expect(handleClick).toHaveBeenCalledTimes(1);
        expect(eventCallback).toHaveBeenNthCalledWith(1, {
            eventType: 'onValueChange',
            componentId: 'OPTION_RADIO_GROUP',
            componentType: 'dropdown_menu_radio_group',
            shouldStartInteraction: false,
            value: undefined,
        });
    });
});
//# sourceMappingURL=DropdownMenu.test.js.map