import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { describe, jest, it, expect } from '@jest/globals';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { SegmentedControlButton, SegmentedControlGroup } from './SegmentedControl';
import { DesignSystemEventProvider } from '../DesignSystemEventProvider';
describe('SegmentedControl', () => {
    const onChangeSpy = jest.fn();
    const eventCallback = jest.fn();
    const Component = ({ valueHasNoPii }) => (_jsx(DesignSystemEventProvider, { callback: eventCallback, children: _jsxs(SegmentedControlGroup, { name: "test", componentId: "segmented_control_group_test", onChange: onChangeSpy, valueHasNoPii: valueHasNoPii, children: [_jsx(SegmentedControlButton, { value: "a", children: "A" }), _jsx(SegmentedControlButton, { value: "b", children: "B" })] }) }));
    it('emits value change events without value', async () => {
        render(_jsx(Component, {}));
        expect(onChangeSpy).not.toHaveBeenCalled();
        expect(eventCallback).not.toHaveBeenCalled();
        const button = screen.getByText('B');
        await userEvent.click(button);
        expect(onChangeSpy).toHaveBeenCalledWith(expect.objectContaining({ target: expect.objectContaining({ value: 'b' }) }));
        expect(eventCallback).toHaveBeenCalledWith({
            eventType: 'onValueChange',
            componentId: 'segmented_control_group_test',
            componentType: 'segmented_control_group',
            shouldStartInteraction: false,
            value: undefined,
        });
    });
    it('emits value change events with value', async () => {
        render(_jsx(Component, { valueHasNoPii: true }));
        expect(onChangeSpy).not.toHaveBeenCalled();
        expect(eventCallback).not.toHaveBeenCalled();
        const button = screen.getByText('B');
        await userEvent.click(button);
        expect(onChangeSpy).toHaveBeenCalledWith(expect.objectContaining({ target: expect.objectContaining({ value: 'b' }) }));
        expect(eventCallback).toHaveBeenCalledWith({
            eventType: 'onValueChange',
            componentId: 'segmented_control_group_test',
            componentType: 'segmented_control_group',
            shouldStartInteraction: false,
            value: 'b',
        });
    });
});
//# sourceMappingURL=SegmentedControl.test.js.map