import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { css } from '@emotion/react';
import { isUndefined } from 'lodash';
import { useState, useRef, useEffect } from 'react';
import { CheckIcon, DangerIcon, LoadingIcon, Typography, WarningIcon, useDesignSystemTheme } from '../../design-system';
import { addDebugOutlineIfEnabled } from '../../design-system/utils/debug';
import { DEFAULT_SPACING_UNIT } from '../../theme/spacing';
export function Stepper({ direction: requestedDirection, currentStepIndex: currentStep, steps, localizeStepNumber, responsive = true, onStepClicked, }) {
    const { theme } = useDesignSystemTheme();
    const ref = useRef(null);
    const { direction } = useResponsiveDirection({ ref, requestedDirection, responsive, enabled: steps.length > 0 });
    if (steps.length === 0) {
        return null;
    }
    const isHorizontal = direction === 'horizontal';
    const currentStepIndex = currentStep ? Math.min(steps.length - 1, Math.max(0, currentStep)) : 0;
    return (_jsx("ol", { ...addDebugOutlineIfEnabled(), css: css(getStepsStyle(theme, isHorizontal)), ref: ref, children: steps.map((step, index) => {
            const isCurrentStep = index === currentStepIndex;
            const isLastStep = index === steps.length - 1;
            const displayEndingDivider = !isLastStep;
            const contentTitleLevel = 4;
            const StepIcon = step.icon;
            const clickEnabled = step.clickEnabled && onStepClicked;
            const { icon, iconBackgroundColor, iconTextColor, titleTextColor, titleAsParagraph, descriptionTextColor, hasStepItemIconBorder, stepItemIconBorderColor, } = getStepContentStyleFields(theme, isCurrentStep, step.status, StepIcon, step.additionalVerticalContent);
            return (_jsx("li", { "aria-current": isCurrentStep, css: css(getStepItemStyle(theme, isHorizontal, isLastStep)), ...(step.status === 'error' && { 'data-error': true }), ...(step.status === 'loading' && { 'data-loading': true }), children: _jsxs(StepContentGrid, { isHorizontal: isHorizontal, children: [_jsx("div", { css: css(getStepItemIconParentStyle(theme, iconBackgroundColor, hasStepItemIconBorder, stepItemIconBorderColor, Boolean(clickEnabled))), onClick: clickEnabled ? () => onStepClicked(index) : undefined, children: StepIcon ? (_jsx(StepIcon, { statusColor: iconTextColor, status: step.status })) : icon ? (_jsx("span", { css: { color: iconTextColor, display: 'flex' }, children: icon })) : (_jsx(Typography.Title, { level: contentTitleLevel, css: { color: `${iconTextColor} !important` }, withoutMargins: true, children: localizeStepNumber(index + 1) })) }), _jsx("span", { onClick: clickEnabled ? () => onStepClicked(index) : undefined, onKeyDown: (event) => {
                                if (event.key === 'Enter' && clickEnabled) {
                                    onStepClicked(index);
                                }
                            }, css: { cursor: clickEnabled ? 'pointer' : undefined }, tabIndex: clickEnabled ? 0 : undefined, role: clickEnabled ? 'button' : undefined, children: titleAsParagraph ? (_jsx(Typography.Text, { withoutMargins: true, css: { flexShrink: 0, color: `${titleTextColor} !important` }, children: step.title })) : (_jsx(Typography.Title, { level: 4, withoutMargins: true, css: { flexShrink: 0, color: `${titleTextColor} !important` }, children: step.title })) }), displayEndingDivider && (_jsx("div", { css: css(getStepEndingDividerStyles(theme, isHorizontal, step.status === 'completed')) })), (step.description || (step.additionalVerticalContent && !isHorizontal)) && (_jsxs("div", { css: css(getStepDescriptionStyles(theme, isHorizontal, isLastStep, descriptionTextColor)), children: [step.description && (_jsx(Typography.Text, { css: css(getStepDescriptionTextStyles(descriptionTextColor)), withoutMargins: true, size: "sm", children: step.description })), step.additionalVerticalContent && !isHorizontal && (_jsx("div", { css: css(getAdditionalVerticalStepContentStyles(theme, Boolean(step.description))), children: step.additionalVerticalContent }))] }))] }) }, index));
        }) }));
}
function getStepsStyle(theme, isHorizontal) {
    return css({
        listStyle: 'none',
        display: 'flex',
        flexDirection: isHorizontal ? 'row' : 'column',
        flexWrap: 'wrap',
        alignItems: 'flex-start',
        gap: isHorizontal ? theme.spacing.sm : theme.spacing.xs,
        width: '100%',
        margin: '0',
        padding: '0',
    });
}
function getStepItemStyle(theme, isHorizontal, isLastStep) {
    return css({
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'flex-start',
        flexGrow: isLastStep ? 0 : 1,
        marginRight: isLastStep && isHorizontal ? theme.spacing.lg + theme.spacing.md : 0,
        width: isHorizontal ? undefined : '100%',
    });
}
function getStepContentStyleFields(theme, isCurrentStep, status, icon, additionalVerticalContent) {
    const fields = getStepContentStyleFieldsFromStatus(theme, isCurrentStep, status, !isUndefined(additionalVerticalContent));
    if (icon) {
        return {
            ...fields,
            icon: undefined,
            iconBackgroundColor: undefined,
            iconTextColor: getCustomIconColor(theme, isCurrentStep, status),
            hasStepItemIconBorder: false,
        };
    }
    return fields;
}
function getCustomIconColor(theme, isCurrentStep, status) {
    switch (status) {
        case 'completed':
            return theme.colors.actionLinkDefault;
        case 'loading':
            return theme.colors.textPlaceholder;
        case 'error':
            return theme.colors.textValidationDanger;
        case 'warning':
            return theme.colors.textValidationWarning;
        default:
        case 'upcoming':
            return isCurrentStep ? theme.colors.actionLinkDefault : theme.colors.textPlaceholder;
    }
}
function getStepContentStyleFieldsFromStatus(theme, isCurrentStep, status, hasAdditionalVerticalContent) {
    switch (status) {
        case 'completed':
            return {
                icon: _jsx(CheckIcon, {}),
                iconBackgroundColor: isCurrentStep
                    ? theme.colors.actionLinkDefault
                    : theme.isDarkMode
                        ? theme.colors.blue800
                        : theme.colors.blue100,
                iconTextColor: isCurrentStep ? theme.colors.white : theme.colors.actionLinkDefault,
                titleAsParagraph: false,
                titleTextColor: theme.colors.actionLinkDefault,
                descriptionTextColor: theme.colors.textSecondary,
                hasStepItemIconBorder: true,
                stepItemIconBorderColor: theme.colors.actionDefaultBackgroundPress,
            };
        case 'loading':
            return {
                icon: (_jsx(LoadingIcon, { spin: true, css: { fontSize: isCurrentStep ? theme.typography.fontSizeXl : theme.typography.fontSizeLg } })),
                iconBackgroundColor: undefined,
                iconTextColor: theme.colors.textPlaceholder,
                titleAsParagraph: false,
                titleTextColor: isCurrentStep ? theme.colors.textPrimary : theme.colors.textSecondary,
                descriptionTextColor: theme.colors.textSecondary,
                hasStepItemIconBorder: false,
            };
        case 'error':
            return {
                icon: _jsx(DangerIcon, {}),
                iconBackgroundColor: isCurrentStep ? theme.colors.textValidationDanger : theme.colors.backgroundDanger,
                iconTextColor: isCurrentStep ? theme.colors.white : theme.colors.textValidationDanger,
                titleAsParagraph: false,
                titleTextColor: theme.colors.textValidationDanger,
                descriptionTextColor: theme.colors.textValidationDanger,
                hasStepItemIconBorder: true,
                stepItemIconBorderColor: theme.colors.borderDanger,
            };
        case 'warning':
            return {
                icon: _jsx(WarningIcon, {}),
                iconBackgroundColor: isCurrentStep ? theme.colors.textValidationWarning : theme.colors.backgroundWarning,
                iconTextColor: isCurrentStep ? theme.colors.white : theme.colors.textValidationWarning,
                titleAsParagraph: false,
                titleTextColor: theme.colors.textValidationWarning,
                descriptionTextColor: theme.colors.textValidationWarning,
                hasStepItemIconBorder: true,
                stepItemIconBorderColor: theme.colors.borderWarning,
            };
        default:
        case 'upcoming':
            if (isCurrentStep) {
                return {
                    icon: undefined,
                    iconBackgroundColor: theme.colors.actionLinkDefault,
                    iconTextColor: 'white',
                    titleAsParagraph: false,
                    titleTextColor: theme.colors.actionLinkDefault,
                    descriptionTextColor: hasAdditionalVerticalContent ? theme.colors.textSecondary : theme.colors.textPrimary,
                    hasStepItemIconBorder: false,
                };
            }
            return {
                icon: undefined,
                iconBackgroundColor: undefined,
                iconTextColor: theme.colors.textPlaceholder,
                titleAsParagraph: true,
                titleTextColor: theme.colors.textSecondary,
                descriptionTextColor: theme.colors.textSecondary,
                hasStepItemIconBorder: true,
                stepItemIconBorderColor: theme.colors.border,
            };
    }
}
const MaxHorizontalStepDescriptionWidth = 140;
const StepIconSize = DEFAULT_SPACING_UNIT * 4;
function getStepItemIconParentStyle(theme, iconBackgroundColor, hasStepItemIconBorder, stepItemIconBorderColor, clickEnabled) {
    return css({
        width: StepIconSize,
        height: StepIconSize,
        backgroundColor: iconBackgroundColor,
        borderRadius: theme.borders.borderRadiusFull,
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        fontSize: '20px',
        flexShrink: 0,
        border: hasStepItemIconBorder ? `1px solid ${stepItemIconBorderColor ?? theme.colors.textPlaceholder}` : undefined,
        boxSizing: 'border-box',
        cursor: clickEnabled ? 'pointer' : undefined,
    });
}
function getStepEndingDividerStyles(theme, isHorizontal, isCompleted) {
    const backgroundColor = isCompleted ? theme.colors.actionLinkDefault : theme.colors.border;
    if (isHorizontal) {
        return css({
            backgroundColor,
            height: '1px',
            width: '100%',
            minWidth: theme.spacing.md,
        });
    }
    return css({
        backgroundColor,
        height: '100%',
        minHeight: theme.spacing.lg,
        width: '1px',
        alignSelf: 'flex-start',
        marginLeft: theme.spacing.md,
    });
}
function getStepDescriptionStyles(theme, isHorizontal, isLastStep, textColor) {
    return css({
        alignSelf: 'flex-start',
        width: '100%',
        gridColumn: isHorizontal || isLastStep ? '2 / span 2' : undefined,
        maxWidth: isHorizontal ? MaxHorizontalStepDescriptionWidth : undefined,
        paddingBottom: isHorizontal ? undefined : theme.spacing.sm,
        color: `${textColor} !important`,
    });
}
function getStepDescriptionTextStyles(textColor) {
    return css({
        color: `${textColor} !important`,
    });
}
function getAdditionalVerticalStepContentStyles(theme, addTopPadding) {
    return css({
        paddingTop: addTopPadding ? theme.spacing.sm : 0,
    });
}
function StepContentGrid({ children, isHorizontal }) {
    const { theme } = useDesignSystemTheme();
    if (isHorizontal) {
        return (_jsx("div", { css: {
                display: 'grid',
                gridTemplateColumns: `${StepIconSize}px fit-content(100%) 1fr`,
                gridTemplateRows: `${StepIconSize}px auto`,
                alignItems: 'center',
                justifyItems: 'flex-start',
                gridColumnGap: theme.spacing.sm,
                width: '100%',
            }, children: children }));
    }
    return (_jsx("div", { css: {
            display: 'grid',
            gridTemplateColumns: `${StepIconSize}px minmax(0, 1fr)`,
            alignItems: 'center',
            justifyItems: 'flex-start',
            gridColumnGap: theme.spacing.sm,
            gridRowGap: theme.spacing.xs,
            width: '100%',
            '& > :first-child': {
                // horizontally center the first column (circle/icon)
                justifySelf: 'center',
            },
        }, children: children }));
}
// Ant design uses the same value for their stepper and to works well for us as well.
const MinimumHorizonalDirectionWidth = 532;
// exported for unit test
export function useResponsiveDirection({ requestedDirection = 'horizontal', responsive, enabled, ref, }) {
    const [direction, setDirection] = useState(requestedDirection);
    useEffect(() => {
        if (requestedDirection === 'vertical' || !enabled || !responsive || !ref.current) {
            return;
        }
        let timeoutId;
        const resizeObserver = new ResizeObserver((entries) => {
            timeoutId = requestAnimationFrame(() => {
                if (entries.length === 1) {
                    const width = entries[0].target.clientWidth || 0;
                    setDirection(width < MinimumHorizonalDirectionWidth ? 'vertical' : 'horizontal');
                }
            });
        });
        if (ref.current) {
            resizeObserver.observe(ref.current);
        }
        return () => {
            resizeObserver.disconnect();
            cancelAnimationFrame(timeoutId);
        };
    }, [requestedDirection, enabled, ref, responsive]);
    return { direction };
}
//# sourceMappingURL=Stepper.js.map