import { describe, it, jest, expect } from '@jest/globals';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';

import { Switch } from './Switch';
import { DesignSystemEventProvider, DesignSystemEventProviderAnalyticsEventTypes } from '../DesignSystemEventProvider';

describe('Switch', () => {
  it('handles changes with DesignSystemEventProvider', async () => {
    // Arrange
    const handleOnChange = jest.fn();
    const eventCallback = jest.fn();
    render(
      <DesignSystemEventProvider callback={eventCallback}>
        <Switch componentId="bestSwitchEver" onChange={handleOnChange} />
      </DesignSystemEventProvider>,
    );
    expect(handleOnChange).not.toHaveBeenCalled();
    expect(eventCallback).not.toHaveBeenCalled();

    // Act
    await userEvent.click(screen.getByRole('switch'));

    // Assert
    expect(handleOnChange).toHaveBeenCalledTimes(1);
    expect(eventCallback).toHaveBeenNthCalledWith(1, {
      eventType: 'onValueChange',
      componentId: 'bestSwitchEver',
      componentType: 'switch',
      shouldStartInteraction: false,
      value: true,
    });
  });

  it('handles view event with DesignSystemEventProvider', async () => {
    // Disable IntersectionObserver for useNotifyOnFirstView hook to trigger
    (window as any).IntersectionObserver = undefined;

    const handleOnChange = jest.fn();
    const eventCallback = jest.fn();
    render(
      <DesignSystemEventProvider callback={eventCallback}>
        <Switch
          componentId="bestSwitchEver"
          onChange={handleOnChange}
          analyticsEvents={[DesignSystemEventProviderAnalyticsEventTypes.OnView]}
          checked={true}
        />
      </DesignSystemEventProvider>,
    );
    expect(handleOnChange).not.toHaveBeenCalled();
    expect(eventCallback).toHaveBeenCalled();
    expect(eventCallback).toHaveBeenNthCalledWith(1, {
      eventType: 'onView',
      componentId: 'bestSwitchEver',
      componentType: 'switch',
      shouldStartInteraction: false,
      value: true,
    });
  });
});
