/** @jsxImportSource @emotion/react */
import React, { useCallback } from 'react';

import { useListboxContext } from './ListboxRoot';
import type { ListboxInputProps } from './types';
import { SearchIcon, useDesignSystemTheme } from '../../design-system';
import { Input } from '../../design-system/Input';

export const ListboxInput = ({
  value,
  onChange,
  placeholder,
  'aria-controls': ariaControls,
  'aria-activedescendant': ariaActiveDescendant,
  className,
  options,
}: ListboxInputProps) => {
  const { handleKeyNavigation } = useListboxContext();
  const designSystemTheme = useDesignSystemTheme();

  const handleChange = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onChange(event.target.value);
    },
    [onChange],
  );

  const handleKeyDown = useCallback(
    (event: React.KeyboardEvent<HTMLInputElement>) => {
      // Only handle navigation keys if there are options
      if (options.length > 0 && ['ArrowDown', 'ArrowUp', 'Home', 'End', 'Enter'].includes(event.key)) {
        handleKeyNavigation(event, options);
      }
    },
    [handleKeyNavigation, options],
  );

  return (
    <div
      css={{
        position: 'sticky',
        top: 0,
        background: designSystemTheme.theme.colors.backgroundPrimary,
        zIndex: designSystemTheme.theme.options.zIndexBase + 1,
      }}
    >
      <Input
        componentId="listbox-filter-input"
        role="combobox"
        aria-controls={ariaControls}
        aria-activedescendant={ariaActiveDescendant}
        aria-expanded="true"
        aria-autocomplete="list"
        value={value}
        onChange={handleChange}
        onKeyDown={handleKeyDown}
        placeholder={placeholder}
        prefix={<SearchIcon />}
        className={className}
        allowClear
      />
    </div>
  );
};
