import { useCallback, useReducer } from 'react';

import type { TreeGridInitialState, TreeGridRowId, TreeGridState } from './types';

type TreeGridAction =
  | { type: 'TOGGLE_ROW_EXPANDED'; rowId: string | number }
  | { type: 'SET_ACTIVE_ROW_ID'; rowId: TreeGridRowId | null };

type InternalTreeGridState = Pick<TreeGridState, 'expandedRows' | 'activeRowId'>;

function treeGridReducer(state: InternalTreeGridState, action: TreeGridAction): InternalTreeGridState {
  switch (action.type) {
    case 'TOGGLE_ROW_EXPANDED':
      return {
        ...state,
        expandedRows: { ...state.expandedRows, [action.rowId]: !state.expandedRows[action.rowId] },
      };
    case 'SET_ACTIVE_ROW_ID':
      return { ...state, activeRowId: action.rowId };
    default:
      return state;
  }
}

export interface UseDefaultTreeGridStateOptions {
  initialState?: TreeGridInitialState;
}

export function useDefaultTreeGridState({
  initialState = { expandedRows: {} },
}: UseDefaultTreeGridStateOptions): TreeGridState {
  const [state, dispatch] = useReducer(treeGridReducer, { ...initialState, activeRowId: null });

  const toggleRowExpanded = useCallback((rowId: string | number) => {
    dispatch({ type: 'TOGGLE_ROW_EXPANDED', rowId });
  }, []);

  const setActiveRowId = useCallback((rowId: TreeGridRowId | null) => {
    dispatch({ type: 'SET_ACTIVE_ROW_ID', rowId });
  }, []);

  return {
    ...state,
    toggleRowExpanded,
    setActiveRowId,
  };
}
